@@ -6,7 +6,7 @@ use Bio::Trace::ABIF;
 use Data::Dumper;
 use File::Basename;
 use FASTX::sw 'align';
-$FASTX::Abi::VERSION = '0.3.1';
+$FASTX::Abi::VERSION = '0.4.0';
 
 use constant DEFAULT_MATRIX => { 'wildcard_match'  => 0,
                                  'match'           => 1,
@@ -109,7 +109,7 @@ sub new {
 
     my @ext = ('.abi','.ab1','.ABI','.abI','.AB1','.ab');
     my ($seqname) = basename($self->{filename}, @ext);
-    $object->{sequence_name} = $seqname;
+    $object->{sequence_name} = $abif->sample_name();
 
     # DEFAULTS
     # -----------------------------------
@@ -378,7 +378,7 @@ FASTX::Abi - Read Sanger trace file (chromatograms) in FASTQ format. For traces
 
 =head1 VERSION
 
-version 0.3.1
+version 0.4.0
 
 =head1 SYNOPSIS
 
